@@ -200,7 +200,7 @@
         <location filename="mainwindow.cpp" line="110"/>
         <location filename="mainwindow.cpp" line="192"/>
         <source>Could not create a temporary folder</source>
-        <translation type="unfinished"/>
+        <translation>Non foi posíbel crear un cartafol temporal </translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="130"/>
